%define anolis_release 3

Name:       libiptcdata
Version:    1.0.5
Release:    %{anolis_release}%{?dist}
Summary:    IPTC tag library
License:    LGPLv2+
URL:        https://github.com/ianw/%{name}
Source0:    https://github.com/ianw/%{name}/releases/download/%{name}-%{version}.tar.gz


BuildRequires:  cmake gcc gcc-c++ automake autoconf
BuildRequires:  gettext gettext-devel libtool gtk-doc python3-devel python3-setuptools


%description
libiptcdata is a library, written in C, for manipulating the International 
Press Telecommunications Council (IPTC) metadata stored within multimedia 
files such as images. This metadata can include captions and keywords, 
often used by popular photo management applications. 
The library provides routines for parsing, viewing, modifying, and saving this metadata. 
The library is licensed under the GNU Library General Public License (GNU LGPL). 
The libiptcdata package also includes a command-line utility, iptc, 
for editing IPTC data in JPEG files, as well as Python bindings.

%package devel
Summary:        Headers and libraries for libiptcdata application development
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig

%description devel
The libiptcdata-devel package contains the libraries and include files
that you can use to develop libiptcdata applications.

%package -n python3-%{name}
Summary:        Python bindings for libiptcdata
Requires:       %{name} = %{version}-%{release}
BuildRequires:  make

%description -n python3-%{name}
The libiptcdata-python package contains a Python module that allows Python
applications to use the libiptcdata API for reading and writing IPTC
metadata in images.


%prep
%autosetup
gtkdocize
autoreconf -fiv


%build
export PYTHON_VERSION=%python3_version
%configure --enable-gtk-doc --enable-python --disable-static
%make_build


%install
%make_install
find %{buildroot} -name "*.la" -exec rm -f {} \;
%find_lang %{name} --all-name
%generate_compatibility_deps


%files -f %{name}.lang
%dir %{abidir}
%doc AUTHORS ChangeLog NEWS README TODO
%license COPYING
%{_bindir}/iptc
%{abidir}/*-option.list
%{_libdir}/libiptcdata.so.*
%{abidir}/*.dump

%files -n python3-%{name}
%doc python/README
%doc python/examples/*
%{python3_sitearch}/*.so

%files devel
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/libiptcdata
%{_datadir}/gtk-doc/html/libiptcdata


%changelog
* Fri Apr 07 2023 chen_yu_ao <m15927509890@163.com> - 1.0.5-3
- change spec file format

* Thu Mar 23 2023 chen_yu_ao <m15927509890@163.com> - 1.0.5-2
- optimise format and generate compatibility deps

* Wed Apr 06 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.0.5-1
- Init from upstream version 1.0.5
